==> igniteui-react-charts-16.6.4.tgz: package/ES5/igr-bar-series.js <==
import * as tslib_1 from "tslib";
import { IgrVerticalAnchoredCategorySeries } from "./igr-vertical-anchored-category-series";
import { BarSeries } from "./BarSeries";
import { toPoint, fromRect } from "igniteui-react-core/ES5/componentUtil";
/**
 * Represents a IgxDataChartComponent bar series.
*/
var IgrBarSeries = /** @class */ (function (_super) {
    tslib_1.__extends(IgrBarSeries, _super);
    function IgrBarSeries(props) {
        return _super.call(this, props) || this;
    }
    IgrBarSeries.prototype.createImplementation = function () {
        return new BarSeries();
    };
    Object.defineProperty(IgrBarSeries.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrBarSeries.prototype, "radiusX", {
        /**
         * Gets or sets the x-radius of the ellipse that is used to round the corners of the bar.
        */
        get: function () {
            return this.i.p1;
        },
        set: function (v) {
            this.i.p1 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrBarSeries.prototype, "radiusY", {
        /**
         * Gets or sets the y-radius of the ellipse that is used to round the corners of the bar.
        */
        get: function () {
            return this.i.p2;
        },
        set: function (v) {
            this.i.p2 = +v;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * If possible, will return the best available value bounding box within the series that has the best value match for the world position provided.
    
    * @param world  * The world coordinate for which to get a value bounding box for
    */
    IgrBarSeries.prototype.getSeriesValueBoundingBox = function (world) {
        var iv = this.i.ll(toPoint(world));
        return fromRect(iv);
    };
    /**
     * Scrolls the series to display the item for the specified data item.
     * The series is scrolled by the minimum amount required to place the specified data item within
     * the central 80% of the visible axis.
    
    * @param item  * The data item (item) to scroll to.
    */
    IgrBarSeries.prototype.scrollIntoView = function (item) {
        var iv = this.i.c7(item);
        return (iv);
    };
    /**
     * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
    
    */
    IgrBarSeries.prototype.getItemSpan = function () {
        var iv = this.i.ec();
        return (iv);
    };
    return IgrBarSeries;
}(IgrVerticalAnchoredCategorySeries));
export { IgrBarSeries };

==> igniteui-react-charts-16.6.8.tgz: package/ES5/igr-bar-series.js <==
import * as tslib_1 from "tslib";
import { IgrVerticalAnchoredCategorySeries } from "./igr-vertical-anchored-category-series";
import { BarSeries } from "./BarSeries";
import { toPoint, fromRect } from "igniteui-react-core/ES5/componentUtil";
/**
 * Represents a IgxDataChartComponent bar series.
*/
var IgrBarSeries = /** @class */ (function (_super) {
    tslib_1.__extends(IgrBarSeries, _super);
    function IgrBarSeries(props) {
        return _super.call(this, props) || this;
    }
    IgrBarSeries.prototype.createImplementation = function () {
        return new BarSeries();
    };
    Object.defineProperty(IgrBarSeries.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrBarSeries.prototype, "radiusX", {
        /**
         * Gets or sets the x-radius of the ellipse that is used to round the corners of the bar.
        */
        get: function () {
            return this.i.p3;
        },
        set: function (v) {
            this.i.p3 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrBarSeries.prototype, "radiusY", {
        /**
         * Gets or sets the y-radius of the ellipse that is used to round the corners of the bar.
        */
        get: function () {
            return this.i.p4;
        },
        set: function (v) {
            this.i.p4 = +v;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * If possible, will return the best available value bounding box within the series that has the best value match for the world position provided.
    
    * @param world  * The world coordinate for which to get a value bounding box for
    */
    IgrBarSeries.prototype.getSeriesValueBoundingBox = function (world) {
        var iv = this.i.ln(toPoint(world));
        return fromRect(iv);
    };
    /**
     * Scrolls the series to display the item for the specified data item.
     * The series is scrolled by the minimum amount required to place the specified data item within
     * the central 80% of the visible axis.
    
    * @param item  * The data item (item) to scroll to.
    */
    IgrBarSeries.prototype.scrollIntoView = function (item) {
        var iv = this.i.c8(item);
        return (iv);
    };
    /**
     * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
    
    */
    IgrBarSeries.prototype.getItemSpan = function () {
        var iv = this.i.ed();
        return (iv);
    };
    return IgrBarSeries;
}(IgrVerticalAnchoredCategorySeries));
export { IgrBarSeries };
